@@ -1,3 +1,7 @@
+"""
+Severity model.
+"""
+
 from typing import List, Union
 
 
@@ -6,20 +10,20 @@ class Severity:
     An issue severity.
     """
 
-    def __init__(self, id: str, name: str):
+    def __init__(self, identifier: str, name: str):
         """
         Initialize an issue severity from a name and an id.
-        :param id: Severity id
+        :param identifier: Severity unique identifier
         :param name: Severity display name
         """
-        self.id = id
+        self.identifier = identifier
         self.name = name
 
     def __str__(self) -> str:
-        return self.id
+        return self.identifier
 
     def __repr__(self) -> str:
-        return "'" + self.id + "'"
+        return "'" + self.identifier + "'"
 
 
 #
@@ -50,16 +54,17 @@ def guess(value: str) -> Union[Severity, None]:
     val = value.strip() if value else value
     if not val:
         return SEVERITIES[0]
+    # else
     val = val.lower()
-    if val == "info" or val == "none":
-        return SEVERITIES[1]
-    if val == "low" or val == "minor":
-        return SEVERITIES[2]
-    elif val == "medium" or val == "moderate":
-        return SEVERITIES[3]
-    elif val == "high" or val == "major":
-        return SEVERITIES[4]
-    elif val == "critical" or val == "blocker":
-        return SEVERITIES[5]
-    else:
-        return None
+    sev = None
+    if val in ("info", "none"):
+        sev = SEVERITIES[1]
+    elif val in ("low", "minor"):
+        sev = SEVERITIES[2]
+    elif val in ("medium", "moderate"):
+        sev = SEVERITIES[3]
+    elif val in ("high", "major"):
+        sev = SEVERITIES[4]
+    elif val in ("critical", "blocker"):
+        sev = SEVERITIES[5]
+    return sev
